@@ -1,7 +1,7 @@
 import json
 import yaml
 import os
-from prance import ResolvingParser
+from prance import ResolvingParser, BaseParser
 from prance.util.formats import ParseError
 from prance.util.resolver import RESOLVE_HTTP, RESOLVE_FILES
 from functools import reduce
@@ -26,7 +26,10 @@ class OpenApiSpecDiff(object):
 
 
     def parse_spec(self, spec_path):
+        #try:
         spec = ResolvingParser(spec_path, backend='openapi-spec-validator').specification
+        # except:
+        #     spec = ResolvingParser(spec_path, backend='swagger-spec-validator').specification
         return self.scan_input_spec(spec)
 
     def _process_nested_params(self, input_spec, info, lastkey, nested_data={}):
@@ -48,39 +51,43 @@ class OpenApiSpecDiff(object):
                 to_process = _
         return nested_data
 
+    # def _process_nested_obj(self, type, content, params={}):
+    #     if type == "object":
+    #         for k, info in content:
+    #             return self._process_nested_obj(info["type"], info, {k:})
+    #
+    #     if info.get("type") == "array":
+    #         params[k] = []
+    #         for nparam, ninfo in info.get("properties").items()
+    #             params[k].append({'in': 'body', "name": nparam, "value": "",
+    #                                       "description":ninfo.get("description"), "type": ninfo.get("type"),
+    #                                       "example": ninfo.get("example")})
+
+    def _process_nested_obj(self, body, last_key, payload={}):
+        type = body.get("type")
+        if type == "object":
+            if last_key:
+                payload[last_key] = None
+            data = {}
+            for key, info in body.get("properties").items():
+                data[key] = self._process_nested_obj(info, key)
+                payload = data
+        elif type == "array":
+            payload = []
+            data = self._process_nested_obj(body.get("items"), None)
+            payload.append(data)
+        else:
+            return body.get("example","")
+        return payload
+
     def _process_reqbody(self, reqbody):
         params = []
         for k, v in reqbody.get("content").items():
-            type = v["schema"].get("type")
-            content = v["schema"].get("items")
-            if type == "array":
-                for each in content["properties"]:
-                    print(each, "\n\n")
-                    params.append({'in': 'body', "name": each, "value": ""})
-                for ref, schema_def in content.items():
-                    print(ref, schema_def)
-                    print(">>>>\n\n")
-            else:
-                for each in v["schema"].get("properties",{}):
-                    params.append({'in': 'body', "name": each, "value": ""})
+            payload = self._process_nested_obj(v["schema"],None)
+            # print("finally....."+str(payload),"\n\n\n\n")
+            for param, info in payload.items():
+                params.append({'in': 'body', "name": param, "value": info})
         return params
-        #         schema_def = schema_def.replace("#/", "").replace("/", ".")
-        #         detailed_info = deep_get(input_spec, schema_def)
-        #         params = []
-        #         for p, pspec in detailed_info.get("properties").items():
-        #             if pspec.get("type") == "array":
-        #                 nparams = []
-        #                 for i, j in pspec.get("items").items():
-        #                     _ = j.replace("#/", "").replace("/", ".")
-        #                     _ = self._process_nested_params(input_spec, _, p,{})
-        #                     nparams.append({p:[_[p]]})
-        #                 params.append({"in": "body", "name": p, "value": nparams})
-        #             elif pspec.get("type") == "object":
-        #                 _ = pspec.get('$ref')
-        #                 _ = _.replace("#/", "").replace("/", ".")
-        #                 _ = self._process_nested_params(input_spec, _, p,{})
-        #                 params.append({'in': 'body', "name": p, "value": _})
-        # return params
 
     def scan_input_spec(self, input_spec):
         # if os.path.isdir(input_path):
@@ -112,7 +119,7 @@ class OpenApiSpecDiff(object):
         # print(input_spec["paths"]["/channels"])
         for api, api_info in input_spec["paths"].items():
             for method, method_info in api_info.items():
-                to_replace = input_spec["paths"][api][method]["parameters"]
+                to_replace = input_spec["paths"][api][method].get("parameters")
                 if "requestBody" in method_info:
                     to_replace += self._process_reqbody(method_info["requestBody"])
                 #         if "parameters" in method_info:
@@ -131,7 +138,11 @@ class OpenApiSpecDiff(object):
                 #                                 if _ not in to_replace:
                 #                                     to_replace.append(_)
                 #                 input_spec["paths"][api][method]["parameters"] = to_replace
-                input_spec["paths"][api][method]["parameters"] = to_replace
+                    input_spec["paths"][api][method]["parameters"] = to_replace
+                    # print("replacing reqbody"+str(input_spec["paths"][api][method]["parameters"]))
+                    # print(api, method)
+                    # print("found...."+str(to_replace))
+                    # raise SystemExit
         # print("\n\n\n\nafter\n\n\n")
         # print(input_spec["paths"]["/channels"])
         return input_spec
